; Definitions and structures used by getnetworkparams and getadaptersinfo apis

MAX_ADAPTER_DESCRIPTION_LENGTH	EQU	128
MAX_ADAPTER_NAME_LENGTH			EQU	256
MAX_ADAPTER_ADDRESS_LENGTH		EQU	8  
DEFAULT_MINIMUM_ENTITIES		EQU	32 
MAX_HOSTNAME_LEN				EQU	128
MAX_DOMAIN_NAME_LEN				EQU	128
MAX_SCOPE_ID_LEN				EQU	256

; types

; Node Type

BROADCAST_NODETYPE				EQU	1
PEER_TO_PEER_NODETYPE			EQU	2
MIXED_NODETYPE					EQU	4
HYBRID_NODETYPE					EQU	8

; Adapter Type
 
IF_OTHER_ADAPTERTYPE			EQU	0
IF_ETHERNET_ADAPTERTYPE			EQU	1
IF_TOKEN_RING_ADAPTERTYPE		EQU	2
IF_FDDI_ADAPTERTYPE				EQU	3
IF_PPP_ADAPTERTYPE				EQU	4
IF_LOOPBACK_ADAPTERTYPE			EQU	5
IF_SLIP_ADAPTERTYPE				EQU	6

; IP_ADDRESS_STRING - store an IP address as a dotted decimal string

IP_ADDRESS_STRING	STRUCT
	String		Byte	(4 * 4)	dup(?)
IP_ADDRESS_STRING	ENDS

LPIP_ADDRESS_STRING	typedef	Ptr IP_ADDRESS_STRING

IP_MASK_STRING	STRUCT
	String		Byte	(4 * 4)	dup(?)
IP_MASK_STRING	ENDS

LPIP_MASK_STRING	typedef	Ptr IP_MASK_STRING

; IP_ADDR_STRING - store an IP address with its corresponding subnet mask,
; both as dotted decimal strings

IP_ADDR_STRING	STRUCT
	Next		LPIP_ADDRESS_STRING	?
	IpAddress	IP_ADDRESS_STRING	<>
	IpMask		IP_MASK_STRING		<>
	Context		DWord				?
IP_ADDR_STRING	ENDS

LPIP_ADDR_STRING	typedef Ptr	IP_ADDR_STRING

; ADAPTER_INFO - per-adapter information. All IP addresses are stored as strings

IP_ADAPTER_INFO			STRUCT
	Next				DWord				<>												; LPIP_ADAPTER_INFO
	ComboIndex			DWord				?
	AdapterName			Byte				(MAX_ADAPTER_NAME_LENGTH + 4)			dup(?)
	Description			Byte				(MAX_ADAPTER_DESCRIPTION_LENGTH + 4)	dup(?)
	AddressLength		DWord				?
	Address				Byte				(MAX_ADAPTER_ADDRESS_LENGTH)			dup(?)
	Index				DWord				?
	dwType				DWord				?
	DhcpEnabled			DWord				?
	CurrentIpAddress	LPIP_ADDR_STRING	?
	IpAddressList		IP_ADDR_STRING		<>
	GatewayList			IP_ADDR_STRING		<>
	DhcpServer			IP_ADDR_STRING		<>
	HaveWins			DWord				?
	PrimaryWinsServer	IP_ADDR_STRING		<>
	SecondaryWinsServer	IP_ADDR_STRING		<>
	LeaseObtained		DWord				?
	LeaseExpires		DWord				?
IP_ADAPTER_INFO			ENDS

LPIP_ADAPTER_INFO	typedef Ptr	IP_ADAPTER_INFO

; IP_PER_ADAPTER_INFO - per-adapter IP information such as DNS server list.

IP_PER_ADAPTER_INFO		STRUCT
	AutoconfigEnabled	DWord				?
	AutoconfigActive	DWord				?
	CurrentDnsServer	LPIP_ADDR_STRING	?
	DnsServerList		IP_ADDR_STRING		<>
IP_PER_ADAPTER_INFO		ENDS

LPIP_PER_ADAPTER_INFO	typedef	Ptr IP_PER_ADAPTER_INFO

; FIXED_INFO - the set of IP-related information which does not depend on DHCP

FIXED_INFO				STRUCT
	HostName			Byte	(MAX_HOSTNAME_LEN + 4)		dup(?)
	DomainName			Byte	(MAX_DOMAIN_NAME_LEN + 4)	dup(?)
	CurrentDnsServer	LPIP_ADDR_STRING					?
	DnsServerList		IP_ADDR_STRING						<>
	NodeType			DWord								?
	ScopeId				Byte	(MAX_SCOPE_ID_LEN + 4)		dup(?)
	EnableRouting		DWord								?
	EnableProxy			DWord								?
	EnableDns			DWord								?
FIXED_INFO				ENDS

LPFIXED_INFO	typedef	Ptr	FIXED_INFO

LPSOCKADDR	typedef	Ptr SOCKADDR

SOCKET_ADDRESS	STRUCT
	lpSockaddr			LPSOCKADDR	?
	iSockaddrLength		DWord		?
SOCKET_ADDRESS	ENDS

LPSOCKET_ADDRESS	typedef	Ptr SOCKET_ADDRESS

IP_ADAPTER_UNICAST_ADDRESS	STRUCT
	UNION
		Alignment			ULONGLONG		?
		STRUCT
			dwLength		DWord			?
			Flags			DWord			?
		ENDS
	ENDS
	Next					DWord			?
	Address					SOCKET_ADDRESS	<>
	PrefixOrigin			DWord			?
	SuffixOrigin			DWord			?
	DadState				DWord			?
	ValidLifetime			DWord			?
	PreferredLifetime		DWord			?
	LeaseLifetime			DWord			?
IP_ADAPTER_UNICAST_ADDRESS	ENDS

LPIP_ADAPTER_UNICAST_ADDRESS	typedef Ptr IP_ADAPTER_UNICAST_ADDRESS

IP_ADAPTER_ANYCAST_ADDRESS	STRUCT
	UNION
		Alignment		ULONGLONG		?
		STRUCT
			dwLength	DWord			?
			Flags		DWord			?
		ENDS
	ENDS

	Next				DWord			?
	Address				SOCKET_ADDRESS	<>
IP_ADAPTER_ANYCAST_ADDRESS	ENDS

LPIP_ADAPTER_ANYCAST_ADDRESS	typedef	Ptr IP_ADAPTER_ANYCAST_ADDRESS

IP_ADAPTER_MULTICAST_ADDRESS	STRUCT
	UNION
		Alignment		ULONGLONG		?
		STRUCT
			dwLength	DWord			?
			Flags		DWord			?
		ENDS
	ENDS

	Next				DWord			?
	Address				SOCKET_ADDRESS	<>
IP_ADAPTER_MULTICAST_ADDRESS	ENDS

LPIP_ADAPTER_MULTICAST_ADDRESS	typedef	Ptr IP_ADAPTER_MULTICAST_ADDRESS

IP_ADAPTER_DNS_SERVER_ADDRESS	STRUCT
	UNION
		Alignment		ULONGLONG		?
		STRUCT
			dwLength	DWord			?
			Flags		DWord			?
		ENDS
	ENDS

	Next				DWord			?
	Address				SOCKET_ADDRESS	<>
IP_ADAPTER_DNS_SERVER_ADDRESS	ENDS

LPIP_ADAPTER_DNS_SERVER_ADDRESS	typedef	Ptr IP_ADAPTER_DNS_SERVER_ADDRESS

IP_ADAPTER_ADDRESSES		STRUCT
	UNION
		Alignment			DWord	2 dup(?)

		STRUCT
			dwLength		DWord	?
			IfIndex			DWord	?
		ENDS
	ENDS

	Next					DWord									?
	AdapterName				PCHAR									?
	FirstUnicastAddress		LPIP_ADAPTER_UNICAST_ADDRESS			?
	FirstAnycastAddress		LPIP_ADAPTER_ANYCAST_ADDRESS			?
	FirstMulticastAddress	LPIP_ADAPTER_MULTICAST_ADDRESS			?
	FirstDnsServerAddress	LPIP_ADAPTER_DNS_SERVER_ADDRESS			?
	DnsSuffix				PWCHAR									?
	Description				PWCHAR									?
	FriendlyName			PWCHAR									?
	PhysicalAddress			Byte	(MAX_ADAPTER_ADDRESS_LENGTH)	dup(?)
	PhysicalAddressLength	DWord									?
	Flags					DWord									?
	Mtu						DWord									?
	IfType					DWord									?
	OperStatus				DWORD									?
	Ipv6IfIndex				DWord									?
	ZoneIndices				DWord	(16)							dup(?)
	FirstPrefix				DWord									?
IP_ADAPTER_ADDRESSES		ENDS

LPIP_ADAPTER_ADDRESSES	typedef	Ptr IP_ADAPTER_ADDRESSES

